summaryrefslogtreecommitdiffstats
path: root/kutils/kpluginselector_p.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kutils/kpluginselector_p.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kutils/kpluginselector_p.h')
-rw-r--r--kutils/kpluginselector_p.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kutils/kpluginselector_p.h b/kutils/kpluginselector_p.h
index c9b968c0f..c8a6cb546 100644
--- a/kutils/kpluginselector_p.h
+++ b/kutils/kpluginselector_p.h
@@ -20,7 +20,7 @@
#ifndef KPLUGINSELECTOR_P_H
#define KPLUGINSELECTOR_P_H
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kdelibs_export.h>
@@ -55,13 +55,13 @@ class KPluginSelectionWidget : public QWidget
* @param category The unstranslated category key name.
* @param config Set the KConfigGroup object that holds the
* state of the plugins being enabled or not.
* @param name The name of the widget (passed to QWidget)
*
* @internal
*/
- KPluginSelectionWidget( const QValueList<KPluginInfo*> & plugininfos,
- KPluginSelector * kps, QWidget * parent, const QString & catname,
- const QString & category, KConfigGroup * config = 0,
+ KPluginSelectionWidget( const TQValueList<KPluginInfo*> & plugininfos,
+ KPluginSelector * kps, TQWidget * parent, const TQString & catname,
+ const TQString & category, KConfigGroup * config = 0,
const char * name = 0 );
virtual ~KPluginSelectionWidget();
@@ -72,7 +72,7 @@ class KPluginSelectionWidget : public QWidget
*
* @internal
*/
- QString catName() const;
+ TQString catName() const;
/**
* Tell the KPluginInfo objects to load their state (enabled/disabled).
@@ -88,7 +88,7 @@ class KPluginSelectionWidget : public QWidget
/**
* @return whether the plugin is enabled in the ListView or not.
*/
- bool pluginChecked( const QString & pluginName ) const;
+ bool pluginChecked( const TQString & pluginName ) const;
signals:
/**
@@ -103,7 +103,7 @@ class KPluginSelectionWidget : public QWidget
* argument is the name of the parent component that needs to reload
* its config
*/
- void configCommitted( const QCString & instanceName );
+ void configCommitted( const TQCString & instanceName );
protected:
/**
@@ -114,16 +114,16 @@ class KPluginSelectionWidget : public QWidget
*
* @return Whether the plugin is loaded.
*/
- virtual bool pluginIsLoaded( const QString & pluginName ) const;
+ virtual bool pluginIsLoaded( const TQString & pluginName ) const;
private slots:
/**
- * Called when a QCheckListItem is checked or unchecked. It calls
+ * Called when a TQCheckListItem is checked or unchecked. It calls
* checkDependencies on the Plugin and then updateConfigPage.
*
* @internal
*/
- void executed( QListViewItem * );
+ void executed( TQListViewItem * );
/**
* Called whenever the visible config page should change (plugin
@@ -158,7 +158,7 @@ class KPluginSelectionWidget : public QWidget
* KPluginSelectionWidget is shown and sets the currentplugininfo
* accordingly.
*/
- void tabWidgetChanged( QWidget * );
+ void tabWidgetChanged( TQWidget * );
private:
/**
@@ -168,7 +168,7 @@ class KPluginSelectionWidget : public QWidget
*
* @internal
*/
- QWidget * insertKCM( QWidget * parent, const KCModuleInfo & );
+ TQWidget * insertKCM( TQWidget * parent, const KCModuleInfo & );
/**
* Embed the KCMs for the plugin into the widgetstack
@@ -177,7 +177,7 @@ class KPluginSelectionWidget : public QWidget
*/
void embeddPluginKCMs( KPluginInfo *, bool );
- void init( const QValueList<KPluginInfo*> & plugininfos, const QString & );
+ void init( const TQValueList<KPluginInfo*> & plugininfos, const TQString & );
void checkDependencies( const KPluginInfo * );
struct KPluginSelectionWidgetPrivate;
@@ -55,13 +55,13 @@ class KPluginSelectionWidget : public QWidget
* @param config Set the KConfigGroup object that holds the
* state of the plugins being enabled or not.
- * @param name The name of the widget (passed to QWidget)
+ * @param name The name of the widget (passed to TQWidget)
*
* @internal